SWDEV-341956 - update HIP Dtest with correct coordinates (#2755)

Change-Id: Iaccc4251a984e690d680ce884c6bfcc1093703af

[ROCm/hip commit: 2667f3e225]
This commit is contained in:
ROCm CI Service Account
2022-06-30 13:29:27 +05:30
committed by GitHub
parent 47a1198e18
commit da2888b9c4
11 changed files with 24 additions and 24 deletions
@@ -40,7 +40,7 @@ THE SOFTWARE.
// Device (Kernel) function, it must be void
template <typename T>
__global__ void matrixTranspose(T* out, T* in, const int width) {
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int x = blockDim.x * blockIdx.x + threadIdx.x;
T val = in[x];
for (int i = 0; i < width; i++) {
for (int j = 0; j < width; j++) out[i * width + j] = __shfl(val, j * width + i);